@@ -10,7 +10,7 @@ from urllib.parse import urlparse
 import tomli
 import tomli_w
 from kraken.common import atomic_file_swap, not_none
-from kraken.core import BackgroundTask, Property, TaskStatus
+from kraken.core.api import BackgroundTask, Property, TaskStatus
 
 from kraken.std.cargo.config import CargoRegistry
 from kraken.std.git.config import dump_gitconfig, load_gitconfig
