@@ -3,10 +3,11 @@ from __future__ import annotations
 import os
 import shlex
 import subprocess as sp
+import time
 from dataclasses import dataclass
 from typing import Dict, List, Optional
 
-from kraken.core import Project, Property, Task, TaskStatus
+from kraken.core.api import Project, Property, Task, TaskStatus
 
 from kraken.std.cargo.manifest import ArtifactKind, CargoMetadata
 from kraken.std.descriptors.resource import BinaryArtifact, LibraryArtifact
@@ -39,6 +40,9 @@ class CargoBuildTask(Task):
     #: Environment variables for the Cargo command.
     env: Property[Dict[str, str]] = Property.default_factory(dict)
 
+    #: Number of times to retry before failing this job
+    retry_attempts: Property[int] = Property.default(0)
+
     #: An output property for the Cargo binaries that are being produced by this build.
     out_binaries: Property[List[CargoBinaryArtifact]] = Property.output()
 
@@ -82,23 +86,42 @@ class CargoBuildTask(Task):
             manifest = CargoMetadata.read(self.project.directory)
             target_dir = self.project.directory / os.getenv("CARGO_TARGET_DIR", "target") / self.target.get()
             for artifact in manifest.artifacts:
-                # Hack to brute force copy multiple lib suffixes
-                filenames = target_dir.glob(artifact.name + "*")
-                for f in filenames:
-                    if artifact.kind is ArtifactKind.BIN:
-                        out_binaries.append(CargoBinaryArtifact(artifact.name, f))
-                    elif artifact.kind is ArtifactKind.LIB:
-                        out_libraries.append(CargoLibraryArtifact(artifact.name, f))
+                # Rust binaries have an extensionless name whereas libraries are prefixed with "lib" and suffixed with
+                #
+                # - ".rlib" for Rust libraries
+                # - ".so" (Linux), ".dylib" (macOS) or ".dll" (Windows) for dynamic Rust and system libraries
+                # - ".a" (Linux, macOS) or ".lib" (Windows) for static system libraries
+                #
+                # We create all options for libraries and check for presence of at least one later.
+                if artifact.kind is ArtifactKind.BIN:
+                    out_binaries.append(CargoBinaryArtifact(artifact.name, target_dir / artifact.name))
+                elif artifact.kind is ArtifactKind.LIB:
+                    base_name = f"lib{artifact.name}"
+                    for file_extension in ["rlib", "so", "dylib", "dll", "a", "lib"]:
+                        filename = ".".join([base_name, file_extension]).replace("-", "_")
+                        out_libraries.append(CargoLibraryArtifact(base_name, target_dir / filename))
 
         self.out_binaries.set(out_binaries)
         self.out_libraries.set(out_libraries)
 
-        result = sp.call(command, cwd=self.project.directory, env={**os.environ, **env})
+        total_attempts = self.retry_attempts.get() + 1
 
-        if result == 0:
-            for out_bin in out_binaries:
-                assert out_bin.path.is_file(), out_bin
-            for out_lib in out_libraries:
-                assert out_lib.path.is_file(), out_lib
+        while total_attempts > 0:
+            result = sp.call(command, cwd=self.project.directory, env={**os.environ, **env})
+
+            if result == 0:
+                # Check that binaries which were due have been built.
+                for out_bin in out_binaries:
+                    assert out_bin.path.is_file(), out_bin
+                # Check that at least one library has been built if libraries were due.
+                assert not out_libraries or any(lib.path.is_file() for lib in out_libraries), out_libraries[0].name
+                break
+            else:
+                total_attempts -= 1
+                self.logger.warn("%s failed with result %s", safe_command, result)
+                self.logger.warn("There are %s attempts remaining", total_attempts)
+                if total_attempts > 0:
+                    self.logger.info("Waiting for 10 seconds before retrying..")
+                    time.sleep(10)
 
         return TaskStatus.from_exit_code(safe_command, result)
