@@ -7,6 +7,8 @@ import abc
 from pathlib import Path
 from typing import TYPE_CHECKING, ClassVar
 
+from kraken.core import TaskStatus
+
 from kraken.std.python.pyproject import Pyproject
 
 if TYPE_CHECKING:
@@ -33,6 +35,11 @@ class PythonBuildSystem(abc.ABC):
     def update_pyproject(self, settings: PythonSettings, pyproject: Pyproject) -> None:
         """A chance to permanently update the Pyproject configuration."""
 
+    @abc.abstractmethod
+    def update_lockfile(self, settings: PythonSettings, pyproject: Pyproject) -> TaskStatus:
+        """Resolve all dependencies of the project and write the exact versions into
+        the correspondig lock file. In the case of Poetry it is poetry.lock."""
+
     @abc.abstractmethod
     def requires_login(self) -> bool:
         """Return True if this build system requires a separate login step (i.e. if the credentials cannot be
