@@ -9,6 +9,7 @@ from typing import List
 
 from kraken.std.python.settings import PythonSettings
 
+from ...cargo.manifest import CargoMetadata
 from . import ManagedEnvironment
 from .poetry import PoetryManagedEnvironment, PoetryPythonBuildSystem
 
@@ -37,12 +38,13 @@ class MaturinPythonBuildSystem(PoetryPythonBuildSystem):
         return ["poetry", "run", "maturin", "build", "--release"]
 
     def dist_dir(self) -> Path:
-        return self.project_directory / "target" / "wheels"
+        metadata = CargoMetadata.read(self.project_directory)
+        return metadata.target_directory / "wheels"
 
 
 class MaturinManagedEnvironment(PoetryManagedEnvironment):
     def install(self, settings: PythonSettings) -> None:
-        super(MaturinManagedEnvironment, self).install(settings)
+        super().install(settings)
         command = ["poetry", "run", "maturin", "develop"]
         logger.info("%s", command)
         sp.check_call(command, cwd=self.project_directory)
