@@ -13,6 +13,7 @@ from typing import TYPE_CHECKING
 from urllib.parse import quote
 
 from kraken.common import NotSet
+from kraken.core import TaskStatus
 
 from kraken.std.python.buildsystem.poetry import PoetryPythonBuildSystem
 from kraken.std.python.pyproject import Pyproject
@@ -41,6 +42,9 @@ class SlapPythonBuildSystem(PythonBuildSystem):
         if "poetry" in pyproject.get("tool", {}):
             PoetryPythonBuildSystem(self.project_directory).update_pyproject(settings, pyproject)
 
+    def update_lockfile(self, settings: PythonSettings, pyproject: Pyproject) -> TaskStatus:
+        return TaskStatus.skipped("not supported")
+
     def requires_login(self) -> bool:
         return False
 
@@ -91,9 +95,10 @@ class SlapManagedEnvironment(ManagedEnvironment):
 
     def install(self, settings: PythonSettings) -> None:
         # Ensure that an environment exists.
-        command = ["slap", "venv", "-ac"]
-        logger.info("%s", command)
-        sp.check_call(command, cwd=self.project_directory)
+        if not self.exists():
+            command = ["slap", "venv", "-ac"]
+            logger.info("%s", command)
+            sp.check_call(command, cwd=self.project_directory)
 
         # Install into the environment.
         command = ["slap", "install", "--ignore-active-venv", "--link"]
