@@ -3,11 +3,12 @@ from __future__ import annotations
 import abc
 import logging
 import os
+import shutil
 import subprocess as sp
-from typing import Iterable, MutableMapping
+from typing import Iterable, List, MutableMapping
 
 from kraken.common.pyenv import VirtualEnvInfo, get_current_venv
-from kraken.core import Project, Task, TaskRelationship, TaskStatus
+from kraken.core.api import Project, Task, TaskRelationship, TaskStatus
 
 from kraken.std.python.buildsystem import ManagedEnvironment
 
@@ -20,6 +21,9 @@ class EnvironmentAwareDispatchTask(Task):
     """Base class for tasks that run a subcommand. The command ensures that the command is aware of the
     environment configured in the project settings."""
 
+    python_dependencies: List[str] = []
+    """Packages that should be installed for this task to run."""
+
     def __init__(self, name: str, project: Project) -> None:
         super().__init__(name, project)
         self.settings = python_settings(project)
@@ -59,6 +63,13 @@ class EnvironmentAwareDispatchTask(Task):
         env = os.environ.copy()
         if self.settings.build_system and self.settings.build_system.supports_managed_environments():
             self.activate_managed_environment(self.settings.build_system.get_managed_environment(), env)
+        if self.python_dependencies and shutil.which(command[0], path=env.get("PATH")) is None:
+            logger.warning("Some Python dependencies of %s are not installed.", self.name)
+            logger.warning("To run this task successfully you should add to the `pyproject.toml` file:")
+            logger.warning("[tool.poetry.dev-dependencies]")
+            for dep in self.python_dependencies:
+                logger.warning('%s = "*"', dep)
+            return TaskStatus.failed("The %s dependencies are missing" % self.python_dependencies)
         logger.info("%s", command)
         result = sp.call(command, cwd=self.project.directory, env=env)
         return self.handle_exit_code(result)
