@@ -3,13 +3,15 @@ from __future__ import annotations
 from pathlib import Path
 from typing import Any, List
 
-from kraken.core import Project, Property
+from kraken.core.api import Project, Property
 
 from .base_task import EnvironmentAwareDispatchTask
 
 
 class Flake8Task(EnvironmentAwareDispatchTask):
     description = "Lint Python source files with Flake8."
+    python_dependencies = ["flake8"]
+
     config_file: Property[Path]
     additional_args: Property[List[str]] = Property.config(default_factory=list)
 
