@@ -4,16 +4,20 @@ import dataclasses
 from pathlib import Path
 from typing import Any, List
 
-from kraken.core import Project, Property
+from kraken.core.api import Project, Property
 
 from .base_task import EnvironmentAwareDispatchTask
 
 
 class IsortTask(EnvironmentAwareDispatchTask):
+    python_dependencies = ["isort"]
+
     check_only: Property[bool] = Property.config(default=False)
     config_file: Property[Path]
     additional_files: Property[List[Path]] = Property.config(default_factory=list)
 
+    # EnvironmentAwareDispatchTask
+
     def get_execute_command(self) -> list[str]:
         command = ["isort", str(self.settings.source_directory)] + self.settings.get_tests_directory_as_args()
         command += [str(p) for p in self.additional_files.get()]
