@@ -1,12 +1,11 @@
 from __future__ import annotations
 
-from kraken.core import Project, Property, Task, TaskStatus
+from kraken.core.api import Project, Property, Task, TaskStatus
 
 from ..settings import PythonSettings, python_settings
 
 
 class LoginTask(Task):
-
     settings: Property[PythonSettings]
 
     def prepare(self) -> TaskStatus | None:
