@@ -3,19 +3,23 @@ from __future__ import annotations
 from pathlib import Path
 from typing import Any, List
 
-from kraken.core import Project, Property
+from kraken.core.api import Project, Property
 
 from .base_task import EnvironmentAwareDispatchTask
 
 
 class MypyTask(EnvironmentAwareDispatchTask):
     description = "Static type checking for Python code using Mypy."
+    python_dependencies = ["mypy"]
+
     config_file: Property[Path]
     additional_args: Property[List[str]] = Property.config(default_factory=list)
     check_tests: Property[bool] = Property.config(default=True)
     use_daemon: Property[bool] = Property.config(default=True)
     python_version: Property[str]
 
+    # EnvironmentAwareDispatchTask
+
     def get_execute_command(self) -> list[str]:
         # TODO (@NiklasRosenstein): Should we somewhere add a task that ensures `.dmypy.json` is in `.gitignore`?
         #       Having it in the project directory makes it easier to just stop the daemon if it malfunctions (which
