@@ -6,7 +6,7 @@ from pathlib import Path
 from typing import Any, List
 
 from kraken.common import flatten
-from kraken.core import Project, Property, TaskStatus
+from kraken.core.api import Project, Property, TaskStatus
 
 from .base_task import EnvironmentAwareDispatchTask
 
@@ -15,11 +15,15 @@ from .base_task import EnvironmentAwareDispatchTask
 
 class PytestTask(EnvironmentAwareDispatchTask):
     description = "Run unit tests using Pytest."
+    python_dependencies = ["pytest"]
+
     tests_dir: Property[Path]
     ignore_dirs: Property[List[Path]] = Property.config(default_factory=list)
     allow_no_tests: Property[bool] = Property.config(default=False)
     marker: Property[str]
 
+    # EnvironmentAwareDispatchTask
+
     def is_skippable(self) -> bool:
         return self.allow_no_tests.get() and self.tests_dir.is_empty() and not self.settings.get_tests_directory()
 
